An object of class "linfun" represents
a function defined on a linear network.
The function as.linfun is generic. The method as.linfun.linim
converts objects of class "linim" (pixel images on a linear
network) to functions on the network.
The method as.linfun.linnet converts a linear network (object
of class "linnet") to a function on the network. The function
values are specified by the argument values.
It should be a vector with one entry for each segment of the network;
any point lying on segment number i will return the value values[i].
If values is missing or NULL, the function values are
taken to be the marks attached to the segments (values=marks(X));
if there are no marks attached to the segments, the function value is
the integer index of the segment (values=seq_len(nsegments(X))).
The method as.linfun.lintess converts a tessellation
on a linear network into a function with a different value
on each tile of the tessellation.
The function values are specified by the argument values.
It should be a vector with one entry for each tile of the tessellation;
any point lying in tile number i will return the value values[i].
If values is missing, the marks of the tessellation
are taken as the function values.
If values is missing and the tessellation has no marks,
or if values is given as NULL,
then the function returns factor values identifying which tile
contains each given point.