Stoyan and Grabarnik (1991) proposed a diagnostic
tool for point process models fitted to spatial point pattern data.
Each point \(x_i\) of the data pattern \(X\)
is given a `mark' or `weight'
$$m_i = \frac 1 {\hat\lambda(x_i,X)}$$
where \(\hat\lambda(x_i,X)\)
is the conditional intensity of the fitted model.
If the fitted model is correct, then the sum of these marks
for all points in a region \(B\) has expected value equal to the
area of \(B\).
The function eem is generic, with methods
for various classes of models. This page documents the method
eem.lppm for the class "lppm".
The argument fit must be a fitted point process model
on a linear network (object of class "lppm").
Such objects are produced by the fitting algorithm lppm).
This fitted model object contains complete
information about the original data pattern and the model that was
fitted to it.
The value returned by eem is the vector
of weights \(m[i]\) associated with the points \(x[i]\)
of the original data pattern. The original data pattern
(in corresponding order) can be
extracted from fit using response.lppm.
The function diagnose.lppm
produces a set of sensible diagnostic plots based on these weights.