Learn R Programming

spatstat.linnet (version 3.5-3)

intensity.lppm: Intensity of Fitted Point Process Model on a Linear Network

Description

Computes the intensity of a fitted point process model on a linear network.

Usage

# S3 method for lppm
intensity(X, ...)

Value

A numeric value or numeric vector (if the model is homogeneous) or a pixel image (object of class "linim")

Arguments

X

A fitted point process model on a linear network (object of class "lppm").

...

Arguments passed to predict.lppm.

Author

Adrian Baddeley Adrian.Baddeley@curtin.edu.au and Greg McSwiggan.

Details

This is a method for the generic function intensity for fitted point process models on a linear network (objects of class "lppm") created by the model-fitting function lppm).

The intensity of a point process model on a linear network is the expected number of random points per unit length (McSwiggan, 2019; Baddeley, Rubak and Turner, 2015, Chapter 17).

The result of intensity.lppm(X) is a numerical value if X is a homogeneous Poisson point process, and a pixel image if X is inhomogeneous. (In the latter case, the resolution of the pixel image is controlled by the arguments ... which are passed to predict.lppm.)

References

Baddeley, A., Rubak, E. and Turner, R. (2015) Spatial Point Patterns: Methodology and Applications with R. Chapman and Hall/CRC Press. .

McSwiggan, G. (2019) Spatial point process methods for linear networks with applications to road accident analysis. PhD thesis, University of Western Australia.

See Also

intensity, intensity.lpp, intensity.ppm.

Type methods(intensity) to see methods for other classes.

Examples

Run this code
  m1 <- lppm(spiders ~ 1)
  intensity(m1)
  mx <- lppm(spiders ~ x)
  intensity(mx)

Run the code above in your browser using DataLab