Learn R Programming

spatstat.linnet (version 3.5-0)

is.connected.linnet: Determine Whether a Linear Network is Connected

Description

Determine whether a linear network is topologically connected.

Usage

# S3 method for linnet
is.connected(X, ...)

Arguments

Value

A logical value.

Details

The command is.connected(X) returns TRUE if the network X consists of a single, topologically-connected piece, and returns FALSE if X consists of several pieces which are not joined together.

The function is.connected is generic, with methods for several classes. This help file documents the method for linear networks, is.connected.linnet.

See Also

is.connected, connected, connected.lpp.

Examples

Run this code
  is.connected(simplenet)

Run the code above in your browser using DataLab