| linearKcross.inhom | R Documentation |
For a multitype point pattern on a linear network,
estimate the inhomogeneous multitype K function
which counts the expected number of points of type j
within a given distance of a point of type i.
linearKcross.inhom(X, i, j, lambdaI=NULL, lambdaJ=NULL,
r=NULL, ..., correction="Ang", normalise=TRUE,
sigma=NULL)
X |
The observed point pattern,
from which an estimate of the cross type |
i |
Number or character string identifying the type (mark value)
of the points in |
j |
Number or character string identifying the type (mark value)
of the points in |
lambdaI |
Intensity values for the points of type |
lambdaJ |
Intensity values for the points of type |
r |
numeric vector. The values of the argument |
correction |
Geometry correction.
Either |
... |
Arguments passed to |
normalise |
Logical. If |
sigma |
Smoothing bandwidth passed to |
This is a counterpart of the function Kcross.inhom
for a point pattern on a linear network (object of class "lpp").
The arguments i and j will be interpreted as
levels of the factor marks(X).
If i and j are missing, they default to the first
and second level of the marks factor, respectively.
The argument r is the vector of values for the
distance r at which K_{ij}(r) should be evaluated.
The values of r must be increasing nonnegative numbers
and the maximum r value must not exceed the radius of the
largest disc contained in the window.
If lambdaI or lambdaJ is missing or NULL, it will
be estimated by kernel smoothing using density.lpp.
If lambdaI is a fitted point process model,
the intensity of points of type i is computed from this model.
If update=TRUE (the default), the model will first be updated
by re-fitting it to the data:
if lambdaI is a multitype point process, it is re-fitted to
the entire dataset X.
if lambdaI is an unmarked point process, it is
re-fitted to the subset of X consisting of points of type
i with the marks removed.
Then to compute the fitted intensity of points of type i,
if lambdaI is a multitype point process, the
predicted intensity of points of type i is computed
if lambdaI is an unmarked point process,
the predicted intensity of the model is computed.
Similarly for lambdaJ.
An object of class "fv" (see fv.object).
The arguments i and j are interpreted as
levels of the factor marks(X). Beware of the usual
trap with factors: numerical values are not
interpreted in the same way as character values.
.
Baddeley, A, Jammalamadaka, A. and Nair, G. (2014) Multitype point process analysis of spines on the dendrite network of a neuron. Applied Statistics (Journal of the Royal Statistical Society, Series C), 63, 673–694.
linearKdot,
linearK.
lam <- table(marks(chicago))/(summary(chicago)$totlength)
lamI <- function(x,y,const=lam[["assault"]]){ rep(const, length(x)) }
lamJ <- function(x,y,const=lam[["robbery"]]){ rep(const, length(x)) }
K <- linearKcross.inhom(chicago, "assault", "robbery", lamI, lamJ)
# using fitted models for the intensity
# fit <- lppm(chicago ~marks + x)
# K <- linearKcross.inhom(chicago, "assault", "robbery", fit, fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.