Learn R Programming

spatstat.linnet (version 3.5-0)

linearKdot: Multitype K Function (Dot-type) for Linear Point Pattern

Description

For a multitype point pattern on a linear network, estimate the multitype \(K\) function which counts the expected number of points (of any type) within a given distance of a point of type \(i\).

Usage

linearKdot(X, i, r=NULL, ..., correction="Ang")

Arguments

Value

An object of class "fv" (see fv.object).

Details

This is a counterpart of the function Kdot for a point pattern on a linear network (object of class "lpp").

The argument i will be interpreted as levels of the factor marks(X). If i is missing, it defaults to the first level of the marks factor.

The argument r is the vector of values for the distance \(r\) at which \(K_{i\bullet}(r)\) should be evaluated. The values of \(r\) must be increasing nonnegative numbers and the maximum \(r\) value must not exceed the radius of the largest disc contained in the window.

References

Baddeley, A, Jammalamadaka, A. and Nair, G. (2014) Multitype point process analysis of spines on the dendrite network of a neuron. Applied Statistics (Journal of the Royal Statistical Society, Series C), 63, 673--694.

See Also

Kdot, linearKcross, linearK.

Examples

Run this code
   K <- linearKdot(chicago, "assault")

Run the code above in your browser using DataLab