Learn R Programming

spatstat.linnet (version 3.5-0)

linearpcfdot.inhom: Inhomogeneous Multitype Pair Correlation Function (Dot-type) for Linear Point Pattern

Description

For a multitype point pattern on a linear network, estimate the inhomogeneous multitype pair correlation function from points of type \(i\) to points of any type.

Usage

linearpcfdot.inhom(X, i, lambdaI, lambdadot, r=NULL, ...,
                   correction="Ang", normalise=TRUE,
                   sigma=NULL, adjust.sigma=1,
                   bw="nrd0", adjust.bw=1)

Arguments

Value

An object of class "fv" (see fv.object).

Details

This is a counterpart of the function pcfdot.inhom for a point pattern on a linear network (object of class "lpp").

The argument i will be interpreted as levels of the factor marks(X). If i is missing, it defaults to the first level of the marks factor.

The argument r is the vector of values for the distance \(r\) at which \(g_{i\bullet}(r)\) should be evaluated. The values of \(r\) must be increasing nonnegative numbers and the maximum \(r\) value must not exceed the radius of the largest disc contained in the window.

If lambdaI or lambdadot is missing or NULL, it will be estimated by kernel smoothing using density.lpp.

If lambdaI is a fitted point process model, the intensity of points of type i is computed from this model. If update=TRUE (the default), the model will first be updated by re-fitting it to the data:

  • if lambdaI is a multitype point process, it is re-fitted to the entire dataset X.

  • if lambdaI is an unmarked point process, it is re-fitted to the subset of X consisting of points of type i.

Then to compute the fitted intensity of points of type i,

  • if lambdaI is a multitype point process, the predicted intensity of points of type i is computed

  • if lambdaI is an unmarked point process, the predicted intensity of the model is computed.

If lambdadot is a fitted point process model, the marginal intensity (total intensity of points of any type) is computed from this model. If update=TRUE (the default), the model will first be updated by re-fitting it to the data:

  • if lambdadot is a multitype point process, it is re-fitted to the entire dataset X.

  • if lambdadot is an unmarked point process, it is re-fitted to unmark(X).

Then to compute the fitted marginal intensity,

  • if lambdadot is a multitype point process, the predicted total intensity of points of any type is computed

  • if lambdadot is an unmarked point process, the predicted intensity of the model is computed.

References

Baddeley, A, Jammalamadaka, A. and Nair, G. (2014) Multitype point process analysis of spines on the dendrite network of a neuron. Applied Statistics (Journal of the Royal Statistical Society, Series C), 63, 673--694.

See Also

linearpcfcross.inhom, linearpcfdot, pcfdot.inhom.

Examples

Run this code
   lam <- table(marks(chicago))/(summary(chicago)$totlength)
   lamI <- function(x,y,const=lam[["assault"]]){ rep(const, length(x)) }
   lam. <- function(x,y,const=sum(lam)){ rep(const, length(x)) }

   g <- linearpcfdot.inhom(chicago, "assault", lamI, lam.)

   # using fitted models for the intensity
   # fit <- lppm(chicago, ~marks + x)
   # linearpcfdot.inhom(chicago, "assault", fit, fit)

Run the code above in your browser using DataLab