mergeTiles.lintess: Merge Groups of Tiles in a Tessellation on a Network

View source: R/lintess.R

mergeTiles.lintessR Documentation

Merge Groups of Tiles in a Tessellation on a Network

Description

Given a tessellation on a linear network, and a factor which classifies the tiles of the tessellation into groups, form the set union of each group of tiles, and construct the tessellation based on these merged tiles.

Usage

 ## S3 method for class 'lintess'
mergeTiles(x, group, ...)

Arguments

x

A tessellation on a network (object of class "lintess").

group

A factor, with one entry for each tile of x, which classifies the tiles into groups.

...

Other arguments, currently ignored.

Value

A tessellation on a network (object of class "lintess").

Author(s)

\adrian

.

See Also

mergeTiles

Examples

  A <- as.lintess(simplenet)
  A
  g <- sample(letters[1:3], nobjects(A), replace=TRUE)
  g
  mergeTiles(A, g) 

spatstat.linnet documentation built on July 30, 2026, 5:10 p.m.