Learn R Programming

spatstat.linnet (version 3.5-0)

nnfromvertex: Nearest Data Point From Each Vertex in a Network

Description

Given a point pattern on a linear network, for each vertex of the network find the nearest data point.

Usage

nnfromvertex(X, what = c("dist", "which"), k = 1)

Arguments

Value

A numeric vector, matrix, or data frame.

Details

For each vertex (node) of the linear network, this algorithm finds the nearest data point to the vertex, and returns either the distance from the vertex to its nearest neighbour in X, or the serial number of the nearest neighbour in X, or both.

If k is an integer, then the k-th nearest neighbour is found instead.

If k is an integer vector, this is repeated for each integer in k.

See Also

nndist.lpp

Examples

Run this code
  X <- runiflpp(5, simplenet)
  nnfromvertex(X)
  nnfromvertex(X, k=1:3)

Run the code above in your browser using DataLab