Learn R Programming

spatstat.linnet (version 3.5-0)

plot.lintess: Plot a Tessellation on a Linear Network

Description

Plot a tessellation or division of a linear network into tiles.

Usage

# S3 method for lintess
plot(x, ...,
        main, add = FALSE,
        style = c("colour", "width", "image"),
        col = NULL, values=marks(x),
        ribbon=TRUE, ribargs=list(), multiplot=TRUE, do.plot=TRUE)

Arguments

Value

(Invisible) colour map.

Details

A tessellation on a linear network L is a partition of the network into non-overlapping pieces (tiles). Each tile consists of one or more line segments which are subsets of the line segments making up the network. A tile can consist of several disjoint pieces.

This function plots the tessellation on the current device. It is a method for the generic plot.

If style="colour", each tile is plotted using segments, drawing segments of different colours.

If style="width", each tile is plotted using segments, drawing segments of different widths.

If style="image", the tessellation is converted to a pixel image, and plotted as a colour image using plot.im.

The colours or widths are determined by the values associated with each tile of the tessellation. If values is missing, the default is to use the marks of the tessellation, or if there are no marks, the names of the tiles.

See Also

lintess

Examples

Run this code
   X <- runiflpp(7, simplenet)
   Z <- divide.linnet(X)
   plot(Z, main="tessellation on network")
   points(as.ppp(X))
   plot(Z, main="tessellation on network",
           values=1:nobjects(Z), style="w")

Run the code above in your browser using DataLab