Learn R Programming

spatstat.linnet (version 3.5-0)

simulate.lppm: Simulate a Fitted Point Process Model on a Linear Network

Description

Generates simulated realisations from a fitted Poisson point process model on a linear network.

Usage

# S3 method for lppm
simulate(object, nsim=1, ...,
                         new.coef=NULL,
                         progress=(nsim > 1),
                         drop=FALSE)

Arguments

Value

A list of length nsim containing simulated point patterns (objects of class "lpp") on the same linear network as the original data used to fit the model. The result also belongs to the class "solist", so that it can be plotted, and the class "timed", so that the total computation time is recorded.

Details

This function is a method for the generic function simulate for the class "lppm" of fitted point process models on a linear network.

Only Poisson process models are supported so far.

Simulations are performed by rpoislpp.

See Also

lppm, rpoislpp, simulate

Examples

Run this code
  fit <- lppm(unmark(chicago) ~ y)
  simulate(fit)[[1]]

Run the code above in your browser using DataLab