powered by
Extract or Change the Names of the Tiles in a Tessellation on a Network.
# S3 method for lintess tilenames(x)# S3 method for lintess tilenames(x) <- value
# S3 method for lintess tilenames(x) <- value
tilenames returns a character vector.
tilenames
A tessellation on a linear network (object of class "lintess").
"lintess"
Character vector giving new names for the tiles.
Adrian Baddeley [email protected], Rolf Turner [email protected] and Ege Rubak [email protected].
These functions extract or change the names of the tiles that make up the tessellation x.
x
If the tessellation is a regular grid, the tile names cannot be changed.
lintess, tiles
lintess
tiles
B <- lineardirichlet(runiflpp(5, simplenet)) tilenames(B) tilenames(B) <- letters[1:5]
Run the code above in your browser using DataLab