| intensity.lppm | R Documentation |
Computes the intensity of a fitted point process model on a linear network.
## S3 method for class 'lppm'
intensity(X, ...)
X |
A fitted point process model on a linear network
(object of class |
... |
Arguments passed to |
This is a method for the generic function intensity
for fitted point process models on a linear network (objects of
class "lppm") created by
the model-fitting function lppm).
The intensity of a point process model on a linear network is the expected number of random points per unit length (McSwiggan, 2019; Baddeley, Rubak and Turner, 2015, Chapter 17).
The result of intensity.lppm(X) is a numerical value if X
is a homogeneous Poisson point process, and a pixel image if X
is inhomogeneous. (In the latter case, the resolution of the pixel
image is controlled by the arguments ... which are passed
to predict.lppm.)
A numeric value or numeric vector (if the model is homogeneous)
or a pixel image (object of class "linim")
and Greg McSwiggan.
.
McSwiggan, G. (2019) Spatial point process methods for linear networks with applications to road accident analysis. PhD thesis, University of Western Australia.
intensity,
intensity.lpp,
intensity.ppm.
Type methods(intensity) to see methods for other classes.
m1 <- lppm(spiders ~ 1)
intensity(m1)
mx <- lppm(spiders ~ x)
intensity(mx)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.