This is a method for the generic function intensity
for fitted point process models on a linear network (objects of
class "lppm") created by
the model-fitting function lppm).
The intensity of a point process model on a linear network is the expected
number of random points per unit length (McSwiggan, 2019;
Baddeley, Rubak and Turner, 2015, Chapter 17).
The result of intensity.lppm(X) is a numerical value if X
is a homogeneous Poisson point process, and a pixel image if X
is inhomogeneous. (In the latter case, the resolution of the pixel
image is controlled by the arguments ... which are passed
to predict.lppm.)