This is a counterpart of the function Kdot
for a point pattern on a linear network (object of class "lpp").
The argument i will be interpreted as
levels of the factor marks(X).
If i is missing, it defaults to the first
level of the marks factor.
The argument r is the vector of values for the
distance \(r\) at which \(K_{i\bullet}(r)\) should be evaluated.
The values of \(r\) must be increasing nonnegative numbers
and the maximum \(r\) value must not exceed the radius of the
largest disc contained in the window.