Computes an estimate of the inhomogeneous linear pair correlation function for a point pattern on a linear network.
linearpcfinhom(X, lambda=NULL, r=NULL, ..., correction="Ang",
normalise=TRUE, normpower=1,
update = TRUE, leaveoneout = TRUE,
sigma=NULL, adjust.sigma=1,
bw="nrd0", adjust.bw=1,
ratio = FALSE)Function value table (object of class "fv").
If ratio=TRUE then the return value also has two
attributes called "numerator" and "denominator"
which are "fv" objects
containing the numerators and denominators of each
estimate of \(g(r)\).
This command computes the inhomogeneous version of the linear pair correlation function from point pattern data on a linear network.
The argument lambda should provide estimated values
of the intensity of the point process at each point of X.
If lambda=NULL, the intensity will be estimated by kernel
smoothing by calling density.lpp with the smoothing
bandwidth sigma, and with any other relevant arguments
that might be present in .... A leave-one-out kernel estimate
will be computed if leaveoneout=TRUE.
If lambda is given,
it may be a numeric vector (of length equal to
the number of points in X), or a function(x,y) that will be
evaluated at the points of X to yield numeric values,
or a pixel image (object of class "im") or a fitted point
process model (object of class "ppm" or "lppm").
If lambda is a fitted point process model,
the default behaviour is to update the model by re-fitting it to
the data, before computing the fitted intensity.
This can be disabled by setting update=FALSE.
The intensity at data points will be computed
by fitted.lppm or fitted.ppm.
A leave-one-out estimate will be computed if leaveoneout=TRUE
and update=TRUE.
If correction="none", the calculations do not include
any correction for the geometry of the linear network.
If correction="Ang", the pair counts are weighted using
Ang's correction (Ang, 2010).
The bandwidth for smoothing the pairwise distances
is determined by arguments ...
passed to density.default, mainly the arguments
bw and adjust. The default is
to choose the bandwidth by Silverman's rule of thumb
bw="nrd0" explained in density.default.
Ang, Q.W. (2010) Statistical methodology for spatial point patterns on a linear network. MSc thesis, University of Western Australia.
Ang, Q.W., Baddeley, A. and Nair, G. (2012) Geometrically corrected second-order analysis of events on a linear network, with applications to ecology and criminology. Scandinavian Journal of Statistics 39, 591--617.
Okabe, A. and Yamada, I. (2001) The K-function method on a network and its computational implementation. Geographical Analysis 33, 271-290.
linearpcf,
linearKinhom,
lpp
X <- rpoislpp(5, simplenet)
fit <- lppm(X ~x)
g <- linearpcfinhom(X, lambda=fit, update=FALSE)
plot(g)
ge <- linearpcfinhom(X, sigma=bw.lppl)
Run the code above in your browser using DataLab