| mergeTiles.lintess | R Documentation |
Given a tessellation on a linear network, and a factor which classifies the tiles of the tessellation into groups, form the set union of each group of tiles, and construct the tessellation based on these merged tiles.
## S3 method for class 'lintess'
mergeTiles(x, group, ...)
x |
A tessellation on a network (object of class |
group |
A |
... |
Other arguments, currently ignored. |
A tessellation on a network (object of class "lintess").
.
mergeTiles
A <- as.lintess(simplenet)
A
g <- sample(letters[1:3], nobjects(A), replace=TRUE)
g
mergeTiles(A, g)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.