mergeTiles.lintess: Merge Groups of Tiles in a Tessellation on a Network
Description
Given a tessellation on a linear network,
and a factor which classifies the tiles of the
tessellation into groups, form the set union of each group of tiles,
and construct the tessellation based on these merged tiles.
Usage
# S3 method for lintess
mergeTiles(x, group, ...)
Value
A tessellation on a network (object of class "lintess").
Arguments
x
A tessellation on a network (object of class "lintess").
group
A factor, with one entry for each tile of x,
which classifies the tiles into groups.