A tessellation on a linear network L is a partition of the
network into non-overlapping pieces (tiles). Each tile consists of one
or more line segments which are subsets of the line segments making up
the network. A tile can consist of several disjoint pieces.
This function plots the tessellation on the current device.
It is a method for the generic plot.
If style="colour", each tile is plotted using
segments, drawing segments of different colours.
If style="width", each tile is plotted using
segments, drawing segments of different widths.
If style="image", the tessellation is converted to a pixel
image, and plotted as a colour image using plot.im.
The colours or widths are determined by the values
associated with each tile of the tessellation. If values is
missing, the default is to use the marks of the tessellation, or if
there are no marks, the names of the tiles.